@@ -9,16 +9,12 @@ class MVPoly(object) :
     def __init__(self, dtype = np.double) :
         self._dtype = dtype 
 
-    # subclasses are encouraged to overide the method
-    # dtype_set_callback(value) below, it can set the
-    # the datatype of the representation.
-
-    def dtype_set_callback(self, value) :
+    def asclass(self, C) :
         """
-        For internal use. Do-nothing base-class default 
-        callback for setting the dtype. 
+        Return a polynomial of the specified class *C*, which
+        must be one of the :class:`MVPoly` subclasses.
         """
-        pass
+        return C(self, dtype=self.dtype)
 
     @property
     def dtype(self) :
@@ -26,7 +22,6 @@ class MVPoly(object) :
 
     @dtype.setter
     def dtype(self, value) :
-        self.dtype_set_callback(value)
         self._dtype = value
 
     def intd(self, *intervals) :
