@@ -32,8 +32,10 @@ class MVPolyDict(mvpoly.base.MVPoly) :
         super(MVPolyDict, self).__init__(**kwd)
         if coef is None :
             coef = {}
+        else :
+            for k, v in coef.iteritems() :
+                coef[k] = np.array(v, dtype = self.dtype)
         self._coef = coef
-        self.dtype_set_callback(self.dtype)
 
     @classmethod
     def init_from_nonzero(self, p, dtype) :
@@ -83,15 +85,6 @@ class MVPolyDict(mvpoly.base.MVPoly) :
         d = { m.key: np.array(1) }
         return MVPolyDict(d, **kwd)
 
-    def dtype_set_callback(self, value) :
-        """
-        For internal use. Sets the datatype of the 
-        coefficients.
-        """
-        dtype = np.dtype(value)
-        for k, v in self.coef.iteritems() :
-            self.coef[k] = np.array(v, dtype = dtype)
-            
     @property
     def coef(self) :
         """
@@ -292,6 +285,12 @@ class MVPolyDict(mvpoly.base.MVPoly) :
             return -1
         return max(degs)
     
+    def astype(self, dtype) :
+        """
+        Return a polynomial using the specified *dtype* for the
+        coefficients.
+        """
+        return MVPolyDict.init_from_nonzero(self, dtype=dtype)
 
     def eval(self, *args) :
         """
