@@ -3,6 +3,26 @@ import scipy.signal
 import mvpoly.util.common
 import warnings
 
+def array_enlarge(a, shape) :
+    """
+    Enlarge the :class:`numpy.array` *a* with zeros so that the 
+    result has the given *shape*. It is an error to attempt
+    to reduce any dimension with this function. 
+    """
+    if len(a.shape) != len(shape) :
+        raise(ValueError, "dimensions differ")
+    b = np.zeros(shape, dtype=a.dtype)
+    idx = tuple(slice(0, n, 1) for n in a.shape)
+    b[idx] = a
+    return b
+
+def dimension_pad(S, n) :
+    """
+    Return a shape tuple extended so that it has *n*
+    dimensions
+    """
+    return S + tuple(1 for i in range(n-len(S)))
+
 def int(p, d, dtype) :
     """
     Integrate the multivatiate polynomial whose coefficients
@@ -139,13 +159,6 @@ def convn(a, b) :
         b.shape = dimension_pad(sb, len(sa))
     return scipy.signal.convolve(a, b)
 
-def dimension_pad(S, n) :
-    """
-    Return a shape tuple extended so that it has *n*
-    dimensions
-    """
-    return S + tuple(1 for i in range(n-len(S)))
-
 def horner(p, dtype=float, *args) :
     """
     Evaluate polynomial with coefficients array *p* at 
