@@ -88,6 +88,54 @@ class TestMVPolyInit(unittest.TestCase) :
                 self.assertTrue(p.dtype == r.dtype, "dtype")
 
 
+class TestMVPolyAsType(unittest.TestCase) :
+
+    def test_conversion_to_float(self) :
+        for C in classes :
+            x, y = C.monomials(2, dtype=int)
+            p = (x + 2*y - 4)**3
+            self.assertTrue(p[3,0] == 1, "integer test-case setup")
+            q = p.astype(float)
+            self.assertTrue(q[3,0] == 1.0, "convert to float")
+
+    def test_conversion_to_int(self) :
+        for C in classes :
+            x, y = C.monomials(2, dtype=float)
+            p = (x + 2*y - 4)**3
+            self.assertTrue(p[3,0] == 1.0, "float test-case setup")
+            q = p.astype(float)
+            self.assertTrue(q[3,0] == 1, "convert to int")
+
+    def test_roundtrip(self) :
+        for C in classes :
+            x, y = C.monomials(2, dtype=int)
+            p = (x + 2*y - 4)**3
+            q = p.astype(float)
+            r = q.astype(int)
+            self.assertTrue(p == r, "roundtrip int-float-int")
+
+    def test_dtype_property(self) :
+        for C in classes :
+            x, y = C.monomials(2, dtype = int)
+            p = (x + 2*y - 4)**3
+            q = p.astype(float)
+            self.assertTrue(q.dtype == float, "astype() modifies dtype")
+
+
+class TestMVPolyAsClass(unittest.TestCase) :
+
+    def test_roundtrip(self) :
+        perms = itertools.permutations(classes, 2)        
+        for perm in perms :
+            for dtype in [int, float, np.float64] :
+                x, y = perm[0].monomials(2, dtype=dtype)
+                p = (x + y + 1)**3                
+                q = p.asclass(perm[1])
+                r = q.asclass(perm[0])
+                self.assertTrue(p == r, "equality")
+                self.assertTrue(p.dtype == r.dtype, "dtype")
+
+
 class TestMVPolyGetitem(unittest.TestCase) :
 
     def test_getitem_numargs_zero(self) :
