@@ -37,21 +37,6 @@ class TestMVPolyCubeDtype(unittest.TestCase) :
             self.assertTrue(q.dtype == int,
                             "bad dtype: %s" % repr(q.dtype))
 
-    def test_construct_dtype_delegated(self) :
-
-        def check_dtype(self, p, dtype) :
-            self.assertTrue(p.dtype == dtype,
-                            "bad dtype: %s" % repr(p.dtype))
-            self.assertTrue(p.coef.dtype == dtype,
-                            "bad base dtype: %s" % repr(p.coef.dtype))
-
-        p = MVPolyCube([1, 2], dtype = int) 
-        check_dtype(self, p, int)
-        p.dtype = float
-        check_dtype(self, p, float)
-        p.dtype = complex
-        check_dtype(self, p, complex)
-
 class TestMVPolyCubeSetitem(unittest.TestCase) :
 
     def test_regression_broadcast(self) :
